# Generated by Django 3.1.7 on 2021-04-08 19:15

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0011_globalpermissions_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='announcement',
            name='valid_from',
            field=models.DateTimeField(default=django.utils.timezone.now, verbose_name='Date and time from when to show'),
        ),
    ]
