# Generated by Django 3.2.12 on 2022-02-23 18:03

import ckeditor.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0036_additionalfields_helptext_required'),
    ]

    operations = [
        migrations.CreateModel(
            name='StaticContentWidget',
            fields=[
                ('dashboardwidget_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='core.dashboardwidget')),
                ('content', ckeditor.fields.RichTextField(verbose_name='Content')),
            ],
            options={
                'verbose_name': 'Static content widget',
                'verbose_name_plural': 'Static content widgets',
            },
            bases=('core.dashboardwidget',),
        ),
    ]
