{
  systemProperties {
    availableLanguages {
      code
      nameTranslated
      nameLocal
      cookie
    }
    sitePreferences {
      themePrimary
      themeSecondary
      themeLogo {
        url
      }
      generalTitle
      accountPersonPreferPhoto
      footerImprintUrl
      footerPrivacyUrl
    }
  }
}
