# Generated by Django 3.2.13 on 2022-04-19 16:50

import django.contrib.postgres.fields
from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0039_personal_ical_url'),
    ]

    operations = [
        migrations.AlterField(
            model_name='oauthapplication',
            name='allowed_scopes',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=255), blank=True, null=True, size=None, verbose_name='Allowed scopes that clients can request'),
        ),
    ]
