{% extends "core/base.html" %}

{% load i18n %}

{% block browser_title %}{% trans "Verify your email address" %}{% endblock %}
{% block page_title %}{% trans "Verify your email address" %}{% endblock %}

{% block content %}

  <div class="container">
    <div class="card red">
      <div class="card-content white-text">
        <div class="material-icons iconify small left" data-icon="mdi:alert-octagon-outline"></div>
        <span class="card-title">{% blocktrans %}Verify your email!{% endblocktrans %}</span>
        <p>
          {% blocktrans %}
            This part of the site requires us to verify that you are who you claim to be.
            For this purpose, we require that you verify ownership of your e-mail address.
          {% endblocktrans %}
        </p>
        <p>
          {% blocktrans %}
            We have sent an e-mail to you for verification.
            Please click on the link inside this e-mail. Please
            contact us if you do not receive it within a few minutes.
          {% endblocktrans %}
        </p>
        {% include "core/partials/admins_list.html" %}
      </div>
    </div>
  </div>

{% endblock %}
