{# -*- engine:django -*- #}

{% extends "core/base.html" %}

{% load material_form i18n any_js %}

{% block extra_head %}
  {{ form.media.css }}
  {% include_css "select2-materialize" %}
{% endblock %}

{% block browser_title %}{% blocktrans %}Assign permission{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Assign permission{% endblocktrans %}{% endblock %}

{% block content %}
  <p class="flow-text">
    {% trans "Selected permission" %}: {{ object }}
  </p>

  <form method="post">
    {% csrf_token %}
    <input type="hidden" name="step" value="{{ step }}">
    {% form form=form %}{% endform %}
    <button type="submit" class="btn green waves-effect waves-light">
      <i class="material-icons left iconify" data-icon="mdi:content-save-outline"></i>
      {% trans "Assign" %}
    </button>
  </form>

  {% include_js "select2-materialize" %}
  {{ form.media.js }}
{% endblock %}
