{# -*- engine:django -*- #}

{% extends "core/base_print.html" %}

{% load i18n %}

{% block browser_title %}{% blocktrans %}Test PDF generation{% endblocktrans %}{% endblock %}
{% block page_title %}{% blocktrans %}Test PDF generation{% endblocktrans %}{% endblock %}

{% block content %}
  <div class="alert primary">
    <p>
      <i class="material-icons iconify left" data-icon="mdi:information-outline"></i>
      {% blocktrans %}
        This simple view can be used to ensure the correct function of the built-in PDF generation system.
      {% endblocktrans %}
    </p>
  </div>
{% endblock %}
