# Generated by Django 3.1.4 on 2020-12-21 13:38

import django.contrib.sites.managers
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('core', '0006_dashboard_widget_size'),
    ]

    operations = [
        migrations.CreateModel(
            name='DashboardWidgetOrder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('order', models.PositiveIntegerField(verbose_name='Order')),
                ('person', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.person', verbose_name='Person')),
                ('site', models.ForeignKey(default=1, editable=False, on_delete=django.db.models.deletion.CASCADE, to='sites.site')),
                ('widget', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='core.dashboardwidget', verbose_name='Dashboard widget')),
            ],
            options={
                'verbose_name': 'Dashboard widget order',
                'verbose_name_plural': 'Dashboard widget orders',
            },
            managers=[
            ],
        ),
    ]
