{# -*- engine:django -*- #}

{% extends "core/base.html" %}

{% load material_form i18n %}

{% block browser_title %}{% blocktrans %}Accept invitation{% endblocktrans %}{% endblock %}
{% block no_page_title %}{% endblock %}

{% block extra_head %}
  {{ form.media.css }}
{% endblock %}

{% block content %}
  <div class="row">
  <div class="col m1 l2 xl3"></div>
  <div class="col s12 m10 l8 xl6">
    <div class="card">
      <form method="post">
        <div class="card-content">
          <div class="card-title">{% trans "Accept your invitation" %}</div>
          <div class="alert primary">
            <div>
              <i class="material-icons left">info</i>
              {% blocktrans %}
                Please enter your invitation code to register
                your new user account:
              {% endblocktrans %}
            </div>
          </div>
          {% csrf_token %}
          {% form form=form %}{% endform %}
        </div>
        <div class="card-action-light">
          <button type="submit" class="btn green waves-effect waves-light">
            <i class="material-icons left">card_giftcard</i>
            {% trans "Accept invite" %}
          </button>
        </div>
      </form>
    </div>
  </div>
  {{ form.media.js }}
{% endblock %}
