# Generated by Django 3.2.8 on 2021-11-05 10:37

import django.contrib.postgres.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0025_oauth_align_user_fk'),
    ]

    operations = [
        migrations.AddField(
            model_name='oauthapplication',
            name='allowed_scopes',
            field=django.contrib.postgres.fields.ArrayField(base_field=models.CharField(max_length=32), blank=True, null=True, size=None, verbose_name='Allowed scopes that clients can request'),
        ),
    ]
