<a href="{{ result.object.get_absolute_url|default:"#" }}" class="collection-item search-item">
  {{ result.object }}
  <i class="material-icons secondary-content search-result-icon iconify" data-icon="mdi:{{ result.object.icon_ }}"></i>
</a>
