{% extends "core/base.html" %}

{% load i18n material_form %}

{% block browser_title %}{% trans "Signup" %}{% endblock %}
{% block page_title %}{% trans "Signup" %}{% endblock %}

{% block content %}
  <div class="alert warning">
    <p>
      <i class="material-icons iconify left" data-icon="mdi:alert-outline"></i>
      {% blocktrans %}Already have an account? Then please <a href="{{ login_url }}">sign in</a>.{% endblocktrans %}
    </p>
  </div>

  <form method="post" action="{% url 'account_signup' %}">
    {% csrf_token %}
    {% form form=form %}{% endform %}
    {% if redirect_field_value %}
      <input type="hidden" name="{{ redirect_field_name }}" value="{{ redirect_field_value }}" />
    {% endif %}
    {% trans "Sign up" as caption %}
    {% include "core/partials/save_button.html" with caption=caption icon="mdi:account-plus-outline" %}
  </form>

{% endblock %}
