{% load material_form material_form_internal %}
{% part bound_field.field %}<{{ field.widget.component|default:'dmc-textarea' }}>
  <div class="row">
    <div{% attrs bound_field 'group' %}
      id="id_{{ bound_field.html_name }}_container"
      class="input-field col s12{% if field.required %} required{% endif %}{% if bound_field.errors %} has-error{% endif %}"
    {% endattrs %}>
      {% part field label %}
        <label{% attrs bound_field 'label' %}
          for="{{ bound_field.id_for_label }}"
          {% if bound_field.value %}class="active"{% endif %}
        {% endattrs %}>{{ bound_field.label }}</label>
      {% endpart %}
      <div class="margin-top-35">
      {% part field prefix %}{% endpart %}{% part field control %}
        {{ bound_field }}
      {% endpart %}
      </div>
      {% part field help_text %}{% if field.help_text %}
        <div class="help-block">{{ bound_field.help_text|safe }}</div>
      {% endif %}
      {% endpart %}{% part field errors %}
        {% if bound_field.errors %}
          {% include  'material/field_errors.html' %}
        {% endif %}
      {% endpart %}{{ hidden_initial }}
    </div>
  </div></{{ field.widget.component|default:'dmc-textarea' }}>{% endpart %}
