# Generated by Django 3.2.4 on 2021-07-24 13:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0019_fix_uniqueness_per_site'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pdffile',
            name='person',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='pdf_files', to='core.person', verbose_name='Owner'),
        ),
    ]
