{% extends "core/base.html" %}

{% load i18n material_form %}

{% block browser_title %}{% trans "Third-party Account Login Failure" %}{% endblock %}
{% block page_title %}{% trans "Third-party Account Login Failure" %}{% endblock %}

{% block content %}
  <div class="container">
    <div class="card red">
      <div class="card-content white-text">
        <div class="material-icons iconify small left" data-icon="mdi:alert-octagon-outline"></div>
        <span class="card-title">{% blocktrans %}Third-party Account Login Failure.{% endblocktrans %}</span>
        <p>
          {% blocktrans %}
            An error occurred while attempting to login via your third-party account.
            Please contact one of your site administrators.
          {% endblocktrans %}
        </p>
        {% include "core/partials/admins_list.html" %}
      </div>
    </div>
  </div>
{% endblock %}
