# Generated by Django 3.1.4 on 2021-01-04 13:39

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0008_data_check_result'),
    ]

    operations = [
        migrations.AddField(
            model_name='dashboardwidgetorder',
            name='default',
            field=models.BooleanField(default=False, verbose_name='Part of the default dashboard'),
        ),
        migrations.AlterField(
            model_name='dashboardwidgetorder',
            name='person',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='core.person', verbose_name='Person'),
        ),
        migrations.AlterModelOptions(
            name='dashboardwidget',
            options={'permissions': (('edit_default_dashboard', 'Can edit default dashboard'),),
                     'verbose_name': 'Dashboard Widget', 'verbose_name_plural': 'Dashboard Widgets'},
        ),
    ]
