# Generated by Django 3.2.15 on 2022-10-03 18:38

from django.db import migrations, models
import django.utils.timezone
import oauth2_provider.generators
import oauth2_provider.models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0042_pdffile_empty'),
    ]

    operations = [
        migrations.AddField(
            model_name='taskuserassignment',
            name='additional_button_icon',
            field=models.CharField(blank=True, max_length=255, verbose_name='Additional button icon'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='additional_button_title',
            field=models.CharField(blank=True, max_length=255, verbose_name='Additional button title'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='additional_button_url',
            field=models.URLField(blank=True, verbose_name='Additional button URL'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='back_url',
            field=models.URLField(blank=True, verbose_name='Back URL'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='error_message',
            field=models.TextField(blank=True, verbose_name='Error message'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='success_message',
            field=models.TextField(blank=True, verbose_name='Success message'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='progress_title',
            field=models.CharField(blank=True, max_length=255, verbose_name='Progress title'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='redirect_on_success_url',
            field=models.URLField(blank=True, verbose_name='Redirect on success URL'),
        ),
        migrations.AddField(
            model_name='taskuserassignment',
            name='title',
            field=models.CharField(default='Data are processed', max_length=255, verbose_name='Title'),
            preserve_default=False,
        ),
    ]
