@page {
  padding: 0;
  margin: 0;
}

table.small-print,
td.small-print,
th.small-print {
  font-size: 10pt;
}

tr {
  border-bottom: 1px solid rgba(0, 0, 0, 0.3);
}

td,
th {
  padding: 1px;
}

td.rotate,
th.rotate {
  text-align: center;
  transform: rotate(-90deg);
}
